//____________________________________________________________________________
/*!

\class    genie::LHAPDF6

\brief    LHAPDF6 library interface.
          Concrete implementation of the PDFModelI interface.

\author   Costas Andreopoulos <constantinos.andreopoulos \at cern.ch>
          University of Liverpool & STFC Rutherford Appleton Laboratory

\created  March 20, 2018

\cpright  Copyright (c) 2003-2022, The GENIE Collaboration
          For the full text of the license visit http://copyright.genie-mc.org          
*/
//____________________________________________________________________________

#ifndef _GENIE_LHAPDF6_INTERFACE_H_
#define _GENIE_LHAPDF6_INTERFACE_H_

#include "Framework/Conventions/GBuild.h"
#include "Physics/PartonDistributions/PDFModelI.h"
#include <string>
using std::string;

namespace LHAPDF
{
  class PDF;
}

namespace genie {

class LHAPDF6 : public PDFModelI {

public:

  LHAPDF6();
  LHAPDF6(string config);
  virtual ~LHAPDF6();

  // Implement the PDFModelI interface

  double UpValence   (double x, double Q2) const;
  double DownValence (double x, double Q2) const;
  double UpSea       (double x, double Q2) const;
  double DownSea     (double x, double Q2) const;
  double Strange     (double x, double Q2) const;
  double Charm       (double x, double Q2) const;
  double Bottom      (double x, double Q2) const;
  double Top         (double x, double Q2) const;
  double Gluon       (double x, double Q2) const;
  PDF_t  AllPDFs     (double x, double Q2) const;

  // Override the default "Configure" implementation
  // of the Algorithm interface

  void Configure (const Registry & config);
  void Configure (string config);

private:

  void LoadConfig (void);

  string fSetName;
  int    fMemberID;

#ifdef __GENIE_LHAPDF6_ENABLED__
  LHAPDF::PDF * fLHAPDF;
#endif

};

}         // genie namespace
#endif    // _GENIE_LHAPDF6_INTERFACE_H_
